@@ -18,6 +18,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+import operator
+
 from . import invocation
 from . import verification
 
@@ -31,6 +33,11 @@ class ArgumentError(Exception):
     pass
 
 
+__tracebackhide__ = operator.methodcaller(
+    "errisinstance", (ArgumentError, VerificationError)
+)
+
+
 def _multiple_arguments_in_use(*args):
     return len([x for x in args if x]) > 1
 
@@ -41,7 +48,11 @@ def _invalid_argument(value):
 
 def _invalid_between(between):
     if between is not None:
-        start, end = between
+        try:
+            start, end = between
+        except Exception:
+            return True
+
         if start > end or start < 0:
             return True
     return False
@@ -55,7 +66,7 @@ def _get_wanted_verification(
     if _multiple_arguments_in_use(atleast, atmost, between):
         raise ArgumentError(
             "You can set only one of the arguments: 'atleast', "
-            "'atmost' or 'between'.""")
+            "'atmost' or 'between'.")
     if _invalid_argument(atleast):
         raise ArgumentError("'atleast' argument has invalid value.\n"
                             "It should be at least 1.  You wanted to set it "
@@ -63,12 +74,13 @@ def _get_wanted_verification(
     if _invalid_argument(atmost):
         raise ArgumentError("'atmost' argument has invalid value.\n"
                             "It should be at least 1.  You wanted to set it "
-                            "to: %i""" % atmost)
+                            "to: %i" % atmost)
     if _invalid_between(between):
-        raise ArgumentError("""'between' argument has invalid value.
-            It should consist of positive values with second number not greater
-            than first e.g. [1, 4] or [0, 3] or [2, 2]
-            You wanted to set it to: %s""" % between)
+        raise ArgumentError(
+            """'between' argument has invalid value.
+It should consist of positive values with second number not greater
+than first e.g. (1, 4) or (0, 3) or (2, 2).
+You wanted to set it to: %s""" % (between,))
 
     if atleast:
         return verification.AtLeast(atleast)
@@ -124,7 +136,6 @@ def verify(obj, times=1, atleast=None, atmost=None, between=None,
     if inorder:
         verification_fn = verification.InOrder(verification_fn)
 
-    # FIXME?: Catch error if obj is neither a Mock nor a known stubbed obj
     theMock = _get_mock_or_raise(obj)
 
     class Verify(object):
@@ -143,7 +154,7 @@ class _OMITTED(object):
 OMITTED = _OMITTED()
 
 
-def when(obj, strict=None):
+def when(obj, strict=True):
     """Central interface to stub functions on a given `obj`
 
     `obj` should be a module, a class or an instance of a class; it can be
@@ -210,8 +221,6 @@ def when(obj, strict=None):
     if isinstance(obj, str):
         obj = get_obj(obj)
 
-    if strict is None:
-        strict = True
     theMock = _get_mock(obj, strict=strict)
 
     class When(object):
@@ -395,7 +404,7 @@ def verifyNoUnwantedInteractions(*objs):
     """
 
     if objs:
-        theMocks = list(map(_get_mock_or_raise, objs))
+        theMocks = map(_get_mock_or_raise, objs)
     else:
         theMocks = mock_registry.get_registered_mocks()
 
@@ -412,7 +421,7 @@ def verifyStubbedInvocationsAreUsed(*objs):
 
     """
     if objs:
-        theMocks = list(map(_get_mock_or_raise, objs))
+        theMocks = map(_get_mock_or_raise, objs)
     else:
         theMocks = mock_registry.get_registered_mocks()
 
